# Async-Notify #

Async-Notify is a simple, asyncio-based notification library for Apps.

Notify is built on top of python asyncio for send notifications asynchronous with support of twilio, telegram, o365, email, slack, onesignal and many others.

### Why Async-Notify? ###

The finality of Async-Notify is to provide us a subset of communication providers for sending different notifications in a non-blocking mode..
The main goal of Async-Notify is using only asyncio-based technologies.

### Requirements ###

* Python >= 3.8
* asyncio (https://pypi.python.org/pypi/asyncio/)

### Quick Tutorial ###

Currently Async-Notify supports the following providers:

* Amazon SES
* Email (SMTP)
* Gmail
* Office 365
* Telegram (requires aiogram)
* Twilio (SMS)
* OneSignal
* Twitter
* XMPP stanzas

#### Future work: ####

* Slack
* Facebook Messenger
* Discord
* IRC

### How do I get set up? ###

* Summary of set up
* Configuration
* Dependencies
* Database configuration
* How to run tests
* Deployment instructions

### Contribution guidelines ###

Please have a look at the Contribution Guide

* Writing tests
* Code review

### Who do I talk to? ###

* Repo owner or admin
* Other community or team contact

### License ###

Async-Notify is copyright of Jesus Lara (https://phenobarbital.info) and is licensed under BSD license. I am providing code in this repository under an open source licenses, remember, this is my personal repository; the license that you receive is from me and not from my employeer.
